{pkgs, ...}: {
    programs = {
        home-manager.enable = true;

        git = {
            enable = true;
            userName = "GPD Game User";
            userEmail = "user@gpd.local";
        };

        vim = {
            enable = true;
            defaultEditor = true;
        };

        zsh = {
            enable = true;
            enableSyntaxHighlighting = true;

            oh-my-zsh = {
                enable = true;
                plugins = [ "sudo" "git" "golang" "thefuck" "kubectl" "emoji" "pip" "npm" "yarn" "vscode" ];
                theme = "agnoster";
            };
        };

        waybar = {
            enable = true;
            systemd.enable = true;
            systemd.target = "default.target";
            # see https://github.com/theCode-Breaker/riverwm/blob/main/waybar/river/config-river
            # https://blog.cascade.moe/posts/hyprland-configure/
            settings = {
                mainBar = import ./config/waybar.nix;
            };

            style = import ./config/waybar-style.nix;
        };

        kitty = {
            enable = true;
            font = {
                name = "Powerline";
                size = 12;
            };

            keybindings = {
                "ctrl+c" = "copy_or_interrupt";
                "ctrl+v" = "paste_from_clipboard";
            };

            shellIntegration = {
                enableZshIntegration = true;
                enableBashIntegration = true;
            };

            settings = {
                background_opacity = "0.8";
            };
        };

        rbw = {
            enable = true;
            settings = {
                base_url = "https://pass.sense-t.eu.org";
                email = "sense-t@sense-t.eu.org";
                lock_timeout = 300;
                pinentry = "gnome3";
            };
        };

        wlogout = {
            enable = false;
        };
    };
}